@@ -253,6 +253,7 @@ class process:
     def getStdout(self):
         """Get current stdout"""
         self.close()
+        self._open()
         return self.pipe.stdout
 
     def write(self,data):
@@ -857,3 +858,53 @@ def reVerSplitToPV(x):
             'PV':"",
             'PR':"",
             'PVR':""}.copy()
+
+def getPkgUses(fullpkg):
+    """Get USE and IUSE from package"""
+    category,slash,pkg = fullpkg.partition('/')
+    pkgCategory = '/var/db/pkg/{0}'.format(category)
+    packages = filter(lambda x:x['PN'] == pkg,
+               map(reVerSplitToPV,
+               filter(lambda x:x,
+               map(lambda x:reVerSplit.search(x),
+               listDirectory(pkgCategory)))))
+    if not packages:
+        return None
+    usePath = os.path.join(pkgCategory,packages[-1]['PF'],"USE")
+    iusePath = os.path.join(pkgCategory,packages[-1]['PF'],"IUSE")
+    iuse = open(iusePath,'r').read().strip().split() \
+           if os.path.exists(iusePath) else \
+           []
+    use = open(usePath,'r').read().strip().split() \
+           if os.path.exists(usePath) else \
+           []
+    return (map(lambda x:x[1:] if x.startswith("+") else x,
+            filter(lambda x:x,
+            use)),
+            map(lambda x:x[1:] if x.startswith("+") else x,
+            filter(lambda x:x,
+            iuse)))
+
+def getPkgActiveUses(fullpkg):
+    """Get active uses from package"""
+    res = getPkgUses(fullpkg)
+    if not res:
+        return None
+    return list(set(res[0]) & set(res[1]))
+
+def getSquashList():
+    """Get supprted squashfs compressions method"""
+    wantMethod = set(["lzo","lzma","xz","gzip"])
+    usesSquashFs = getPkgActiveUses("sys-fs/squashfs-tools")
+    if not usesSquashFs:
+        return ["gzip"]
+    else:
+        return map(lambda x:{"lzma":"xz"}.get(x,x),
+               list(set(usesSquashFs) & wantMethod))
+
+def getAvailableX11Drivers():
+    """Get available x11 drivers"""
+    xorg_modules_dir = '/usr/lib/xorg/modules/drivers'
+    return map(lambda x: x[:-7],
+           filter(lambda x:x.endswith('_drv.so'),
+           listDirectory(xorg_modules_dir)))
